const Prism = require('prismjs');
const loadLanguages = require('prismjs/components/');

//console.log(loadLanguages(['ruby']));

const DEFAULTS = {
  plugins: [],
  init: () => {},
  defaultLanguageForUnknown: undefined,
  defaultLanguageForUnspecified: undefined,
  defaultLanguage: undefined
};

function loadPrismLang(lang) {
  if (!lang) return undefined;
  let langObject = Prism.languages[lang];
  if (langObject === undefined) {
    console.log('...', lang);
    loadLanguages([lang]);
    langObject = Prism.languages[lang];
  }
  return langObject;
}

function loadPrismPlugin(name) {
  try {
    require(`prismjs/plugins/${name}/prism-${name}`);
  } catch (e) {
    throw new Error(
      `Cannot load Prism plugin "${name}". Please check the spelling.`
    );
  }
}

function selectLanguage(options, lang) {
  let langToUse = lang;
  if (langToUse === '' && options.defaultLanguageForUnspecified !== undefined) {
    langToUse = options.defaultLanguageForUnspecified;
  }
  let prismLang = loadPrismLang(langToUse);
  if (
    prismLang === undefined &&
    options.defaultLanguageForUnknown !== undefined
  ) {
    langToUse = options.defaultLanguageForUnknown;
    prismLang = loadPrismLang(langToUse);
  }
  return [langToUse, prismLang];
}

function highlight(markdownit, options, text, lang) {
  let langToUse, prismLang;
  [langToUse, prismLang] = selectLanguage(options, lang);
  const code = prismLang
    ? Prism.highlight(text, prismLang)
    : markdownit.utils.escapeHtml(text);
  const classAttribute = langToUse
    ? ` class="${markdownit.options.langPrefix}${langToUse}"`
    : '';
  return `<pre${classAttribute}><code${classAttribute}>${code}</code></pre>`;
}

function checkLanguageOption(options, optionName) {
  const language = options[optionName];
  if (language !== undefined && loadPrismLang(language) === undefined) {
    throw new Error(
      `Bad option ${optionName}: There is no Prism language '${language}'.`
    );
  }
}

function markdownItPrism(markdownit, useroptions) {
  const options = Object.assign({}, DEFAULTS, useroptions);

  checkLanguageOption(options, 'defaultLanguage');
  checkLanguageOption(options, 'defaultLanguageForUnknown');
  checkLanguageOption(options, 'defaultLanguageForUnspecified');
  options.defaultLanguageForUnknown =
    options.defaultLanguageForUnknown || options.defaultLanguage;
  options.defaultLanguageForUnspecified =
    options.defaultLanguageForUnspecified || options.defaultLanguage;

  options.plugins.forEach(loadPrismPlugin);
  options.init(Prism);

  markdownit.options.highlight = (...args) =>
    highlight(markdownit, options, ...args);
}

module.exports = markdownItPrism;
